@@ -16,7 +16,7 @@ package e;
  `  |/  V  V  `   V  )||  |()|  ||(  V   '  V /\  \|  '
     `   `  `      `  / |  |()|  | \  '      '<||>  '
                     (  |  |()|  |  )\        /|/
-                   __\ |__|()|__| /__\______/|/
+        v1.18      __\ |__|()|__| /__\______/|/
                   (vvv(vvvv)(vvvv)vvv)______|/
                   __                __             __
      __  ______  / /__  ____ ______/ /_  ___  ____/ /
@@ -34,7 +34,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.17';
+our $VERSION = '1.18';
 
 =head1 SYNOPSIS
 
